@@ -55,6 +55,8 @@ class FillingParser(HTMLParser.HTMLParser):
         self.in_select = None
         self.skip_next = False        
         self.errors = errors or {}
+        if isinstance(self.errors, (str, unicode)):
+            self.errors = {None: self.errors}
         self.in_error = None
         self.skip_error = False
         self.use_all_keys = use_all_keys
@@ -191,9 +193,10 @@ class FillingParser(HTMLParser.HTMLParser):
         if (self.error_class
             and self.errors.get(self.get_attr(attrs, 'name'))):
             self.add_class(attrs, self.error_class)
-        if t in ('text', 'hidden', 'submit', 'reset', 'button'):
-            self.set_attr(attrs, 'value', value or
-                          self.get_attr(attrs, 'value', ''))
+        if t in ('text', 'hidden'):
+            if value is None:
+                value = self.get_attr(attrs, 'value', '')
+            self.set_attr(attrs, 'value', value)
             self.write_tag('input', attrs, startend)
             self.skip_next = True
             self.add_key(name)
@@ -231,6 +234,12 @@ class FillingParser(HTMLParser.HTMLParser):
             self.write_tag('input', attrs, startend)
             self.skip_next = True
             self.add_key(name)
+        elif t == 'submit' or t == 'reset' or t == 'button':
+            self.set_attr(attrs, 'value', value or
+                          self.get_attr(attrs, 'value', ''))
+            self.write_tag('input', attrs, startend)
+            self.skip_next = True
+            self.add_key(name)
         else:
             assert 0, "I don't know about this kind of <input>: %s (pos: %s)" \
                    % (t, self.getpos())
@@ -276,37 +285,6 @@ class FillingParser(HTMLParser.HTMLParser):
         self.write_tag('option', attrs)
         self.skip_next = True
 
-    def update_schema(self, attrs):
-        name = self.get_attr(attrs, "name")
-        if not name:
-            return
-        v = compound.All()
-        message = self.get_attr(attrs, "form:message")
-        required = self.get_attr(attrs, "form:required", "no").lower()
-        required = (required == "yes") or (required == "true")
-        if required:
-            v.validators.append(validators.NotEmpty(messages=get_messages(validators.NotEmpty, message)))
-        t = self.get_attr(attrs, "form:validate", None)
-        if t:
-            # validatorname[:argument]
-            i = t.find(":")
-            if i > -1:
-                args = t[i+1:] # TODO: split on commas?
-                t = t[:i].lower()
-            else:
-                args = None
-                t = t.lower()
-            # get the validator class by name
-            vclass = self.validators.get(t)
-            if not vclass:
-                raise ValueError, "Invalid validation type: " + t
-            if args:
-                vinst = vclass(args, messages=get_messages(vclass, message)) # TODO: if something takes more than 1 string argument, wrap in a function which parses args
-            else:
-                vinst = vclass(messages=get_messages(vclass, message))
-            v.validators.append(vinst)
-        self._schema.add_field(name, v)
-
     def write_text(self, text):
         self.content.append(text)
 
